#[non_exhaustive]pub enum EncryptedFileInfo {
V2(V2EncryptedFileInfo),
}Expand description
Information about the encryption of a file.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
V2(V2EncryptedFileInfo)
Information about a file encrypted using version 2 of the attachment encryption protocol.
Implementations
Sourceimpl EncryptedFileInfo
impl EncryptedFileInfo
Sourcepub fn version(&self) -> &str
pub fn version(&self) -> &str
Get the version of the attachment encryption protocol.
This matches the v field in the serialized data.
Sourcepub fn custom_data(&self) -> Option<&JsonObject>
pub fn custom_data(&self) -> Option<&JsonObject>
Get the data of the attachment encryption protocol, if it doesn’t match one of the known variants.