#[non_exhaustive]pub struct ImageInfo {
pub height: Option<UInt>,
pub width: Option<UInt>,
pub mimetype: Option<String>,
pub size: Option<UInt>,
pub thumbnail_info: Option<Box<ThumbnailInfo>>,
pub thumbnail_source: Option<MediaSource>,
pub blurhash: Option<String>,
pub thumbhash: Option<Base64>,
pub is_animated: Option<bool>,
}Expand description
Metadata about an image.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.height: Option<UInt>The height of the image in pixels.
width: Option<UInt>The width of the image in pixels.
mimetype: Option<String>The MIME type of the image, e.g. “image/png.”
size: Option<UInt>The file size of the image in bytes.
thumbnail_info: Option<Box<ThumbnailInfo>>Metadata about the image referred to in thumbnail_source.
thumbnail_source: Option<MediaSource>The source of the thumbnail of the image.
blurhash: Option<String>thumbhash: Option<Base64>is_animated: Option<bool>If this flag is true, the original image SHOULD be assumed to be animated. If this flag
is false, the original image SHOULD be assumed to NOT be animated.
If a sending client is unable to determine whether an image is animated, it SHOULD leave the flag unset.
Receiving clients MAY use this flag to optimize whether to download the original image rather than a thumbnail if it is animated, but they SHOULD NOT trust this flag.
Implementations